@@ -1220,16 +1220,23 @@ get_window_pixbuf (MetaWindow *window,
                    int        *width,
                    int        *height)
 {
-  Pixmap pmap;
+  cairo_surface_t *surface;
   GdkPixbuf *pixbuf, *scaled;
   double ratio;
 
-  pmap = meta_compositor_get_window_pixmap (window->display->compositor,
+  surface = meta_compositor_get_window_surface (window->display->compositor,
                                             window);
-  if (pmap == None)
+  if (surface == NULL)
     return NULL;
 
-  pixbuf = meta_ui_get_pixbuf_from_pixmap (pmap);
+  meta_error_trap_push (NULL);
+
+  pixbuf = meta_ui_get_pixbuf_from_surface (surface);
+  cairo_surface_destroy (surface);
+
+  if (meta_error_trap_pop_with_return (NULL, FALSE) != Success)
+    g_clear_object (&pixbuf);
+
   if (pixbuf == NULL) 
     return NULL;
 
@@ -2065,7 +2072,7 @@ meta_screen_queue_workarea_recalc (MetaScreen *screen)
 
 
 #ifdef WITH_VERBOSE_MODE
-static char *
+static const gchar *
 meta_screen_corner_to_string (MetaScreenCorner corner)
 {
   switch (corner)
@@ -2078,6 +2085,8 @@ meta_screen_corner_to_string (MetaScreenCorner corner)
       return "BottomLeft";
     case META_SCREEN_BOTTOMRIGHT:
       return "BottomRight";
+    default:
+      break;
     }
 
   return "Unknown";
@@ -2291,6 +2300,8 @@ meta_screen_calc_workspace_layout (MetaScreen          *screen,
             }
         }
       break;
+    default:
+      break;
     }
 
   if (i != grid_area)
@@ -2691,6 +2702,9 @@ meta_screen_sn_event (SnMonitorEvent *event,
                   "Received startup canceled for %s\n",
                   sn_startup_sequence_get_id (sequence));
       break;
+
+    default:
+      break;
     }
 }
 #endif
