@@ -25,7 +25,10 @@
 #include "common.h"
 #include "types.h"
 
-Window meta_frame_get_xwindow (MetaFrame *frame);
+void   meta_frame_get_mask     (MetaFrame        *frame,
+                                cairo_t          *cr);
+
+Window meta_frame_get_xwindow  (MetaFrame        *frame);
 
 void   meta_frame_calc_borders (MetaFrame        *frame,
                                 MetaFrameBorders *borders);
