@@ -31,7 +31,7 @@ typedef enum
 } MetaExitCode;
 
 /* exit immediately */
-void meta_exit (MetaExitCode code);
+void meta_exit (MetaExitCode code) __attribute__((noreturn));
 
 /* g_main_loop_quit() then fall out of main() */
 void meta_quit (MetaExitCode code);
