@@ -178,7 +178,7 @@ int      meta_ui_get_drag_threshold       (MetaUI *ui);
 
 MetaUIDirection meta_ui_get_direction (void);
 
-GdkPixbuf *meta_ui_get_pixbuf_from_pixmap (Pixmap   pmap);
+GdkPixbuf *meta_ui_get_pixbuf_from_surface (cairo_surface_t *surface);
 
 #include "tabpopup.h"
 #include "tile-preview.h"
