@@ -239,7 +239,6 @@ meta_accel_label_draw (GtkWidget *widget,
                        cairo_t   *cr)
 {
   MetaAccelLabel *accel_label = META_ACCEL_LABEL (widget);
-  GtkMisc *misc = GTK_MISC (accel_label);
   GtkTextDirection direction;
   int ac_width;
   GtkAllocation allocation;
@@ -258,10 +257,11 @@ meta_accel_label_draw (GtkWidget *widget,
       PangoLayout *accel_layout;
       GtkLabel *label = GTK_LABEL (widget);
       gint x, y, xpad, ypad;
-      gfloat xalign, yalign;
+      gint margin_start, margin_end, margin_top, margin_bottom;
+      gfloat yalign;
 
       label_layout = gtk_label_get_layout (GTK_LABEL (accel_label));
-      gtk_misc_get_alignment (misc, &xalign, &yalign);
+      yalign = gtk_label_get_yalign (GTK_LABEL (accel_label));
 
       cairo_save (cr);
 
@@ -271,9 +271,9 @@ meta_accel_label_draw (GtkWidget *widget,
         cairo_translate (cr, ac_width, 0);
       if (gtk_label_get_ellipsize (label))
         pango_layout_set_width (label_layout,
-                                pango_layout_get_width (label_layout) 
+                                pango_layout_get_width (label_layout)
                                 - ac_width * PANGO_SCALE);
-      
+
       allocation.width -= ac_width;
       gtk_widget_set_allocation (widget, &allocation);
       if (GTK_WIDGET_CLASS (meta_accel_label_parent_class)->draw)
@@ -283,12 +283,18 @@ meta_accel_label_draw (GtkWidget *widget,
       gtk_widget_set_allocation (widget, &allocation);
       if (gtk_label_get_ellipsize (label))
         pango_layout_set_width (label_layout,
-                                pango_layout_get_width (label_layout) 
+                                pango_layout_get_width (label_layout)
                                 + ac_width * PANGO_SCALE);
 
       cairo_restore (cr);
 
-      gtk_misc_get_padding (misc, &xpad, &ypad);
+      margin_start = gtk_widget_get_margin_start (widget);
+      margin_end = gtk_widget_get_margin_end (widget);
+      margin_top = gtk_widget_get_margin_top (widget);
+      margin_bottom = gtk_widget_get_margin_bottom (widget);
+
+      xpad = margin_start + margin_end;
+      ypad = margin_top + margin_bottom;
 
       if (direction == GTK_TEXT_DIR_RTL)
         x = xpad;
@@ -318,7 +324,7 @@ meta_accel_label_draw (GtkWidget *widget,
       if (GTK_WIDGET_CLASS (meta_accel_label_parent_class)->draw)
         GTK_WIDGET_CLASS (meta_accel_label_parent_class)->draw (widget, cr);
     }
-  
+
   return FALSE;
 }
 
